"use client"
import React, { useState } from 'react'
import FormControl from "@mui/material/FormControl";
import OutlinedInput from "@mui/material/OutlinedInput";
import InputLabel from "@mui/material/InputLabel";
import MenuItem from "@mui/material/MenuItem";
import ListItemText from "@mui/material/ListItemText";
import Select, { SelectChangeEvent } from "@mui/material/Select";
import Checkbox from "@mui/material/Checkbox";
import { DemoContainer } from "@mui/x-date-pickers/internals/demo";
import { LocalizationProvider } from "@mui/x-date-pickers/LocalizationProvider";
import { AdapterDayjs } from "@mui/x-date-pickers/AdapterDayjs";
import { SingleInputTimeRangeField } from "@mui/x-date-pickers-pro/SingleInputTimeRangeField";

const ITEM_HEIGHT = 48;
const ITEM_PADDING_TOP = 8;
const MenuProps = {
  PaperProps: {
    style: {
      maxHeight: ITEM_HEIGHT * 4.5 + ITEM_PADDING_TOP,
      width: 250,
    },
  },
};

const options = [
  "Legal",
  "Financial",
  "Emotional",
  "Domestic",
  "Technical",
  "Career & Development",
  "Educational",
  "Health and Wellness",
];

const weekdays = ["Monday", "Tuesday", "Wednesday", "Thursday", "Friday"];

const weekends = ["Saturday", "Sunday"];


const ProfSignup = () => {

  const [expertise, setExpertise] = useState<string[]>([]);
  const [selectedWeekdays, setSelectedWeekdays] = useState<string[]>([]);
  const [selectedWeekends, setSelectedWeekends] = useState<string[]>([]);

    
    const handleExpertiseChange = (
      event: SelectChangeEvent<string | string[]>
    ) => {
      const value = event.target.value;
      if (Array.isArray(value)) {
        setExpertise(value);
      } else {
        setExpertise([value]);
      }
    };

    const handleWeekdaysChange = (
      event: SelectChangeEvent<typeof weekdays>
    ) => {
      const value = event.target.value;
      if (Array.isArray(value)) {
        setSelectedWeekdays(value);
      } else {
        setSelectedWeekdays([value]);
      }
    };

    const handleWeekendsChange = (
      event: SelectChangeEvent<string | string[]>
    ) => {
      const value = event.target.value;
      if (Array.isArray(value)) {
        setSelectedWeekends(value);
      } else {
        setSelectedWeekends([value]);
      }
    };
  return (
    <>
      <FormControl sx={{ m: 2, width: 400 }}>
        <InputLabel
          id="demo-multiple-checkbox-label"
          className="text-textaid-100"
        >
          -Select Area(s) of Expertise-
        </InputLabel>
        <Select
          labelId="demo-multiple-checkbox-label"
          id="demo-multiple-checkbox"
          multiple
          value={expertise}
          onChange={handleExpertiseChange}
          input={<OutlinedInput label="" />}
          renderValue={(selected) => selected.join(", ")}
          MenuProps={MenuProps}
        >
          {options.map((name) => (
            <MenuItem key={name} value={name}>
              <Checkbox checked={expertise.indexOf(name) > -1} />
              <ListItemText primary={name} />
            </MenuItem>
          ))}
        </Select>
      </FormControl>

      <h2 className="text-blueaid">Availabilty:</h2>
      <FormControl sx={{ m: 2, width: 400 }}>
        <InputLabel
          id="demo-multiple-checkbox-label"
          className="text-textaid-100"
        >
          -Select Weekdays-
        </InputLabel>
        <Select
          labelId="demo-multiple-checkbox-label"
          id="demo-multiple-checkbox"
          multiple
          value={selectedWeekdays}
          onChange={handleWeekdaysChange}
          input={<OutlinedInput label="" />}
          renderValue={(selected) => selected.join(", ")}
          MenuProps={MenuProps}
        >
          {weekdays.map((name) => (
            <MenuItem key={name} value={name}>
              <Checkbox checked={weekdays.indexOf(name) > -1} />
              <ListItemText primary={name} />
            </MenuItem>
          ))}
        </Select>
      </FormControl>
      <div className="w-[90%] px-4 py-5">
        <LocalizationProvider dateAdapter={AdapterDayjs}>
          <DemoContainer components={["SingleInputTimeRangeField"]}>
            <SingleInputTimeRangeField label="From - To" />
          </DemoContainer>
        </LocalizationProvider>
      </div>

      <FormControl sx={{ m: 2, width: 400 }}>
        <InputLabel
          id="demo-multiple-checkbox-label"
          className="text-textaid-100"
        >
          -Select Weekends-
        </InputLabel>
        <Select
          labelId="demo-multiple-checkbox-label"
          id="demo-multiple-checkbox"
          multiple
          value={selectedWeekends}
          onChange={handleWeekendsChange}
          input={<OutlinedInput label="" />}
          renderValue={(selected) => selected.join(", ")}
          MenuProps={MenuProps}
        >
          {weekends.map((name) => (
            <MenuItem key={name} value={name}>
              <Checkbox checked={weekends.indexOf(name) > -1} />
              <ListItemText primary={name} />
            </MenuItem>
          ))}
        </Select>
      </FormControl>
      <div className="w-[90%] px-4 py-5">
        <LocalizationProvider dateAdapter={AdapterDayjs}>
          <DemoContainer components={["SingleInputTimeRangeField"]}>
            <SingleInputTimeRangeField label="From - To" />
          </DemoContainer>
        </LocalizationProvider>
      </div>
    </>
  );
}

export default ProfSignup